@@ -16,7 +16,7 @@ module RailsAdmin
           proc do
             if format = params[:json] && :json || params[:csv] && :csv || params[:xml] && :xml
               request.format = format
-              @schema = params[:schema].symbolize if params[:schema] # to_json and to_xml expect symbols for keys AND values.
+              @schema = HashHelper.symbolize(params[:schema]) if params[:schema] # to_json and to_xml expect symbols for keys AND values.
               @objects = list_entries(@model_config, :export)
               index
             else
