@@ -8,6 +8,14 @@ module RailsAdmin
           # Register field type for the type loader
           RailsAdmin::Config::Fields::Types.register(self)
 
+          OBJECT_ID ||= begin
+            if defined?(Moped::BSON)
+              Moped::BSON::ObjectId
+            elsif defined?(BSON::ObjectId)
+              BSON::ObjectId
+            end
+          end
+
           register_instance_option :label do
             label = ((@label ||= {})[::I18n.locale] ||= abstract_model.model.human_attribute_name name)
             label = 'Id' if label == ''
@@ -26,13 +34,19 @@ module RailsAdmin
             serial?
           end
 
-          def parse_input(params)
-            params[name] = (params[name].blank? ? nil : abstract_model.object_id_from_string(params[name])) if params[name].is_a?(::String)
+          def parse_value(value)
+            value.present? ? OBJECT_ID.from_string(value) : nil
+          rescue BSON::ObjectId::Invalid
+            nil
           rescue => e
             unless ['BSON::InvalidObjectId', 'Moped::Errors::InvalidObjectId'].include? e.class.to_s
               raise e
             end
           end
+
+          def parse_input(params)
+            params[name] = parse_value(params[name]) if params[name].is_a?(::String)
+          end
         end
       end
     end
